<?php

/**
 * @package Auto-Install Free SSL
 * This package is a WordPress Plugin. It issues and installs free SSL certificates in cPanel shared hosting with complete automation.
 *
 * @author Free SSL Dot Tech <support@freessl.tech>
 * @copyright  Copyright (C) 2019-2020, Anindya Sundar Mandal
 * @license    http://www.gnu.org/licenses/gpl-3.0.html GNU General Public License, version 3
 * @link       https://freessl.tech
 * @since      Class available since Release 1.0.0
 *
 *
 *   This program is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 */
namespace AutoInstallFreeSSL\FreeSSLAuto\Admin;

use  AutoInstallFreeSSL\FreeSSLAuto\Acme\Factory as AcmeFactory ;
/**
 * Home page options
 *
 */
class HomeOptions
{
    public  $factory ;
    /**
     * Start up
     */
    public function __construct()
    {
        if ( !defined( 'ABSPATH' ) ) {
            die( __( "Access Denied", 'auto-install-free-ssl' ) );
        }
        $this->factory = new Factory();
    }
    
    /**
     *
     *
     * Previous __construct()
     */
    public function display()
    {
        if ( aifs_is_free_version() ) {
            
            if ( aifs_is_existing_user() ) {
                //Display free Premium License request button
                $this->request_free_premium_license();
            } else {
                wp_redirect( admin_url( 'admin.php?page=aifs_generate_ssl_manually' ) );
            }
        
        }
    }
    
    /**
     *
     * @return false|string
     */
    public function single_domain_get_ssl_file_path()
    {
        $app_settings = aifs_get_app_settings();
        $domain = aifs_get_domain( true );
        $serveralias = 'www.' . $domain;
        //initialize the Acme Factory class
        $acmeFactory = new AcmeFactory( $app_settings['homedir'] . '/' . $app_settings['certificate_directory'], $app_settings['acme_version'], $app_settings['is_staging'] );
        //get the path of SSL files
        $certificates_directory = $acmeFactory->getCertificatesDir();
        //echo $certificates_directory."<br />";
        $certificate = false;
        
        if ( is_file( $certificates_directory . DS . $domain . DS . 'certificate.pem' ) ) {
            $certificate = $certificates_directory . DS . $domain . DS . 'certificate.pem';
        } elseif ( is_file( $certificates_directory . DS . $serveralias . DS . 'certificate.pem' ) ) {
            $certificate = $certificates_directory . DS . $serveralias . DS . 'certificate.pem';
        }
        
        return $certificate;
    }
    
    /**
     *
     *
     * @return string
     */
    public function single_domain_ssl_data()
    {
        $app_settings = aifs_get_app_settings();
        $text_display = "";
        $certificate = $this->single_domain_get_ssl_file_path();
        
        if ( $certificate ) {
            $cert_array = openssl_x509_parse( openssl_x509_read( file_get_contents( $certificate ) ) );
            /*$date = new DateTime('@' . $cert_array['validTo_time_t']);
              $expiry_date = $date->format('Y-m-d H:i:s') . ' ' . date_default_timezone_get();*/
            $expiry_date = str_replace( '-', 'at', wp_date( 'F j, Y - h:i:s A', $cert_array['validTo_time_t'] ) );
            $issuerShort = $cert_array['issuer']['O'];
            //$subjectAltName = str_replace('DNS:', '', $cert_array['extensions']['subjectAltName']);
            if ( $_GET['page'] == "auto_install_free_ssl" ) {
                $text_display .= '<h3 style="color: #0b9e0b;">https://' . aifs_get_domain() . '</h3><br />';
            }
            $text_display .= __( "SSL Expiry date", 'auto-install-free-ssl' ) . ': ' . $expiry_date . '<br />';
            $text_display .= __( "Issuer", 'auto-install-free-ssl' ) . ': ' . $issuerShort . '<br />';
            //echo 'Home directory: '.$this->factory->set_ssl_parent_directory().'<br />';
            $text_display .= '<br /><hr />';
            
            if ( aifs_is_free_version() || !aifs_can_manage_multi_domain__premium_only() ) {
                $certificate = wp_nonce_url( get_site_url() . $_SERVER['REQUEST_URI'], 'aifs_download_ssl', 'aifsdownloadssl' ) . "&domain=" . aifs_get_domain( true );
                $text_display .= '<span class="dashicons dashicons-download" style="color: darkviolet;"></span>&nbsp;<span style="font-size: large; font-weight: bold; color: darkviolet;">' . __( "Downloads", 'auto-install-free-ssl' ) . '</span><br />';
                $text_display .= '<div class="aifs-download"><a href="' . $certificate . '&file=certificate.pem" title="' . __( "Click here to download SSL Certificate", 'auto-install-free-ssl' ) . '">' . __( "SSL", 'auto-install-free-ssl' ) . '</a> &nbsp;&nbsp;&nbsp;| &nbsp;&nbsp;&nbsp;';
                $text_display .= '<a href="' . $certificate . '&file=private.pem" title="' . __( "Click here to download Private Key", 'auto-install-free-ssl' ) . '">' . __( "Private Key", 'auto-install-free-ssl' ) . '</a> &nbsp;&nbsp;&nbsp;| &nbsp;&nbsp;&nbsp;';
                $text_display .= '<a href="' . $certificate . '&file=cabundle.pem" title="' . __( "Click here to download CA Bundle", 'auto-install-free-ssl' ) . '">' . __( "CA Bundle", 'auto-install-free-ssl' ) . '</a></div>';
                $text_display .= '<hr />';
            }
        
        }
        
        return $text_display;
    }
    
    /**
     * Handles free Premium License request
     *
     */
    private function request_free_premium_license()
    {
        if ( !aifs_is_existing_user() ) {
            return;
        }
        $response = [];
        $options = ( get_option( 'aifs_request_free_premium_license' ) ? get_option( 'aifs_request_free_premium_license' ) : add_option( 'aifs_request_free_premium_license' ) );
        //if (isset($_GET['settings-updated']) && $_GET['settings-updated'] === 'true') {
        
        if ( 'POST' === $_SERVER['REQUEST_METHOD'] && isset( $_POST['agree_to_freessl_tech_tos_pp'] ) ) {
            //request license
            //Send domain, admin name and email to FreeSSL.tech server
            $admin_email = get_option( 'admin_email' );
            $admin = get_user_by( 'email', $admin_email );
            //$admin->first_name;
            global  $wp_version ;
            $data = array(
                'body' => array(
                'domain'               => aifs_get_domain( true ),
                'admin_email'          => $admin_email,
                'key'                  => "xX4x0;58CVl3[0~+f[*pH8c*Vg_7ioiKR-69zu~F8itU2(md@8eT5[7J22R7*5&(",
                'admin_first_name'     => $admin->first_name,
                'admin_last_name'      => $admin->last_name,
                'aifs_version'         => AIFS_VERSION,
                'wordpress_version'    => $wp_version,
                'is_free_version'      => aifs_is_free_version(),
                'is_premium'           => aifssl_fs()->is_premium(),
                'can_use_premium_code' => aifssl_fs()->can_use_premium_code(),
                'ip_server'            => $_SERVER['SERVER_ADDR'],
                'ip_user'              => $_SERVER['REMOTE_ADDR'],
            ),
            );
            //Send the request to freessl.tech
            $response = wp_remote_post( "https://pro.freessl.tech/aifs_request_free.php", $data );
            
            if ( $response['response']['code'] === 200 ) {
                $class = "notice-success";
                $font_size = 8;
                $color = "green";
            } else {
                $class = "notice-error";
                $color = "red";
                $font_size = 8;
            }
            
            //if($response['response']['code'] === 200) {
            //echo "<pre>";
            echo  "<br /><br />" ;
            echo  '<div class="notice ' . $class . ' is-dismissible">' ;
            echo  '<span class="dashicons dashicons-info-outline" style="font-size: ' . $font_size . 'em; color: ' . $color . '; float: right; margin-top: 1%; margin-right: 10%;"></span>' ;
            echo  $response['body'] ;
            echo  '</div>' ;
            //echo "</pre>";
            //}
            $options[] = array(
                'agree_to_freessl_tech_tos_pp' => true,
                'sent'                         => $data,
                'received'                     => $response['body'],
            );
            update_option( 'aifs_request_free_premium_license', $options );
        }
        
        ?>
        <div class="wrap">

        <h1><?php 
        echo  AIFS_NAME ;
        ?></h1>

        <table style="width: 100%; margin-bottom: 2%;">
            <tr>
                <td class="card block-body" style="width: 55%; padding-top: 1%; padding-left: 2%;">

				    <?php 
        $heading = __( "Claim Premium License for FREE", 'auto-install-free-ssl' );
        echo  '<h1 style="color: #076507; text-align: center;">' . $heading . '</h1>' ;
        echo  '<br /><h3 style="color: #076507; text-align: center; margin-top: -0.1%;">' . __( "Exclusive offer for the Existing users", 'auto-install-free-ssl' ) . '</h3>' ;
        echo  '<p style="color: #000000; text-align: center; margin-top: -0.1%;">' . __( "The FREE license is valid until December 31, 2022", 'auto-install-free-ssl' ) . '</p>' ;
        echo  '<p style="color: #000000; text-align: center;">' . __( "Unlimited Sites license", 'auto-install-free-ssl' ) . '</p>' ;
        $save_button_text = __( "Request Premium License for Free", 'auto-install-free-ssl' );
        
        if ( !isset( $response['response']['code'] ) || $response['response']['code'] != 200 ) {
            $tos_text = __( "By clicking the '%s' button you acknowledge that you agree with FreeSSL.tech %s & %s.", 'auto-install-free-ssl' );
            $fs_tos = '<a href="https://freessl.tech/terms-of-service" target="_blank">' . __( "Terms of Service", 'auto-install-free-ssl' ) . '</a>';
            $fs_pp = '<a href="https://freessl.tech/privacy-policy" target="_blank">' . __( "Privacy Policy", 'auto-install-free-ssl' ) . '</a>';
            echo  "<p><br />" . sprintf(
                $tos_text,
                $save_button_text,
                $fs_pp,
                $fs_tos
            ) . "<br /><br /></p>" ;
            echo  '<form method="post" action="">' ;
            /*settings_fields( 'aifs_generate_ssl_manually_group' );
              do_settings_sections( 'aifs_generate_ssl_manually_admin' );*/
            $confirmation_text = __( "Are you sure to request FREE Premium License?", 'auto-install-free-ssl' );
            submit_button(
                $save_button_text,
                'button-primary button-hero',
                'agree_to_freessl_tech_tos_pp',
                false,
                'onclick="return aifs_confirm(\'' . $confirmation_text . '\')"'
            );
            //echo '<a href="' . menu_page_url( 'auto_install_free_ssl', false ) . '" id="aifs-cancel" class="page-title-action button">' . __( "Cancel", 'auto-install-free-ssl' ) . '</a>';
            echo  '</form>' ;
        }
        
        ?>


                </td>

                <td style="width: 2%;"></td>

                <td class="card block-body" style="width: 43%; padding-top: 1%; padding-left: 2%;">
                    <h3 class="block-title"><?php 
        echo  __( "How to Claim & Activate the Premium Version", 'auto-install-free-ssl' ) ;
        ?></h3>
                    <p style="color: green;"><?php 
        echo  __( "Video tutorial. Time required: 1 minute.", 'auto-install-free-ssl' ) ;
        ?></p>

                    <iframe width="100%" height="281" src="https://www.youtube.com/embed/wLG8fT3AFqE?start=46" frameborder="0" allow="accelerometer; autoplay; encrypted-media; gyroscope; picture-in-picture" allowfullscreen></iframe>
                </td>

			    <?php 
        /*$forcehttps = new ForceSSL();
          echo $forcehttps->force_ssl_ui();*/
        ?>
            </tr>

        </table>

        <div class="overlay"></div>
        <div class="spanner">
            <div class="loader"></div>
            <p class="loader_text"><?php 
        echo  __( "Processing, please wait ...", 'auto-install-free-ssl' ) ;
        ?></p>
        </div>

        <?php 
        $manually = new GenerateSSLmanually();
        $manually->pro_version_promotion();
        ?>
        <?php 
        echo  aifs_powered_by() ;
        ?>
        </div>
    <?php 
    }

}